@@ -1,7 +1,5 @@
 import unittest
-import sys
 
-from artap.problem import Problem
 try:
     from artap.algorithm_nlopt import NLopt
     from artap.algorithm_nlopt import GN_DIRECT_L
@@ -23,24 +21,12 @@ from artap.results import Results
 from artap.benchmark_functions import Booth
 
 
-class MyProblem(Problem):
-    """ Describe simple one objective optimization problem. """
-    def set(self):
-        self.name = "Booth Problem"
-        self.parameters = [{'name': 'x_1', 'initial_value': 2.5, 'bounds': [-10, 10]},
-                      {'name': 'x_2', 'initial_value': 1.5, 'bounds': [-10, 10]}]
-        self.costs = [{'name': 'F'}]
-
-    def evaluate(self, individual):
-        return [Booth.eval(individual.vector)]
-
-
 class TestNLoptOptimization(unittest.TestCase):
     """ Tests simple one objective optimization problem."""
 
     def run_test(self, method, n_iterations=100):
         try:
-            problem = MyProblem()
+            problem = Booth()
             algorithm = NLopt(problem)
             algorithm.options['verbose_level'] = 0
             algorithm.options['algorithm'] = method
